<?php

/*
 * LMS version 1.11.7 Bastet
 *
 *  (C) Copyright 2001-2009 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: genfake.php,v 1.71 2009/01/13 07:45:50 alec Exp $
 */

// Lastnames

$lastnames[] = "Abbott";
$lastnames[] = "Adamson";
$lastnames[] = "Aimes";
$lastnames[] = "Airey";
$lastnames[] = "Aitken";
$lastnames[] = "Aldiss";
$lastnames[] = "Allen";
$lastnames[] = "Alliband";
$lastnames[] = "Ambler";
$lastnames[] = "Andersen";
$lastnames[] = "Andrews";
$lastnames[] = "Angel";
$lastnames[] = "Anthony";
$lastnames[] = "Arbuckle";
$lastnames[] = "Armstrong";
$lastnames[] = "Arthur";
$lastnames[] = "August";
$lastnames[] = "Bailey";
$lastnames[] = "Balmaves";
$lastnames[] = "Barker";
$lastnames[] = "Barnes";
$lastnames[] = "Bartleson";
$lastnames[] = "Bartlett";
$lastnames[] = "Basford";
$lastnames[] = "Batchelar";
$lastnames[] = "Bates";
$lastnames[] = "Batterson";
$lastnames[] = "Batty";
$lastnames[] = "Beasley";
$lastnames[] = "Beattie";
$lastnames[] = "Bedford";
$lastnames[] = "Bellehausen";
$lastnames[] = "Bennett";
$lastnames[] = "Bird";
$lastnames[] = "Bishop";
$lastnames[] = "Blackman";
$lastnames[] = "Blanchfield";
$lastnames[] = "Blight";
$lastnames[] = "Blok";
$lastnames[] = "Bloom";
$lastnames[] = "Blunt";
$lastnames[] = "Boehm";
$lastnames[] = "Bollard";
$lastnames[] = "Boshier";
$lastnames[] = "Boucherie";
$lastnames[] = "Bowling";
$lastnames[] = "Box";
$lastnames[] = "Boyd";
$lastnames[] = "Bradbury";
$lastnames[] = "Bradley";
$lastnames[] = "Brady";
$lastnames[] = "Brayne";
$lastnames[] = "Breese";
$lastnames[] = "Breeze";
$lastnames[] = "Brennan";
$lastnames[] = "Brent";
$lastnames[] = "Brenton";
$lastnames[] = "Bridge";
$lastnames[] = "Britt";
$lastnames[] = "Brook";
$lastnames[] = "Broom";
$lastnames[] = "Brophy";
$lastnames[] = "Brown";
$lastnames[] = "Bruce";
$lastnames[] = "Buckhurst";
$lastnames[] = "Buckman";
$lastnames[] = "Buckridge";
$lastnames[] = "Buffrey";
$lastnames[] = "Bull";
$lastnames[] = "Burgess";
$lastnames[] = "Burke";
$lastnames[] = "Burland";
$lastnames[] = "Burns";
$lastnames[] = "Burton";
$lastnames[] = "Bushell";
$lastnames[] = "Butler";
$lastnames[] = "Buttsworth";
$lastnames[] = "Byrne";
$lastnames[] = "Cabel";
$lastnames[] = "Cadle";
$lastnames[] = "Calvert";
$lastnames[] = "Cameron";
$lastnames[] = "Campbell";
$lastnames[] = "Campling";
$lastnames[] = "Capon";
$lastnames[] = "Carrigg";
$lastnames[] = "Carson";
$lastnames[] = "Carter";
$lastnames[] = "Cartwright";
$lastnames[] = "Cattee";
$lastnames[] = "Chapman";
$lastnames[] = "Charker";
$lastnames[] = "Charlton";
$lastnames[] = "Chaseling";
$lastnames[] = "Chatfield";
$lastnames[] = "Chipps";
$lastnames[] = "Cignell";
$lastnames[] = "Clark";
$lastnames[] = "Clarke";
$lastnames[] = "Clisby";
$lastnames[] = "Cloudy";
$lastnames[] = "Cloutman";
$lastnames[] = "Cochran";
$lastnames[] = "Coffey";
$lastnames[] = "Cole";
$lastnames[] = "Coleman";
$lastnames[] = "Collin";
$lastnames[] = "Collison";
$lastnames[] = "Comans";
$lastnames[] = "Connellan";
$lastnames[] = "Cook";
$lastnames[] = "Cooper";
$lastnames[] = "Cope";
$lastnames[] = "Corbett";
$lastnames[] = "Cork";
$lastnames[] = "Costigan";
$lastnames[] = "Cox";
$lastnames[] = "Crane";
$lastnames[] = "Cranham";
$lastnames[] = "Crew";
$lastnames[] = "Cross";
$lastnames[] = "Crowe";
$lastnames[] = "Crummy";
$lastnames[] = "Cullen";
$lastnames[] = "Cunningham";
$lastnames[] = "Cupitt";
$lastnames[] = "Curran";
$lastnames[] = "Currums";
$lastnames[] = "Curtis";
$lastnames[] = "Cutler";
$lastnames[] = "Cuttriss";
$lastnames[] = "D'hudson";
$lastnames[] = "Dale";
$lastnames[] = "Dark";
$lastnames[] = "Davey";
$lastnames[] = "Davidson";
$lastnames[] = "Davies";
$lastnames[] = "Davis";
$lastnames[] = "Dawes";
$lastnames[] = "Dawson";
$lastnames[] = "Day";
$lastnames[] = "Dempsey";
$lastnames[] = "Denham";
$lastnames[] = "Dennett";
$lastnames[] = "Dennis";
$lastnames[] = "Dick";
$lastnames[] = "Dixon";
$lastnames[] = "Dobbyn";
$lastnames[] = "Dobson";
$lastnames[] = "Donald";
$lastnames[] = "Donaldson";
$lastnames[] = "Donohoe";
$lastnames[] = "Doolan";
$lastnames[] = "Dornan";
$lastnames[] = "Driver";
$lastnames[] = "Dryden";
$lastnames[] = "Drysdale";
$lastnames[] = "Dunk";
$lastnames[] = "Dunn";
$lastnames[] = "Dunne";
$lastnames[] = "Dunston";
$lastnames[] = "Eccleston";
$lastnames[] = "Edgar";
$lastnames[] = "Edmonds";
$lastnames[] = "Edwards";
$lastnames[] = "Elliot";
$lastnames[] = "Elliott";
$lastnames[] = "Emms";
$lastnames[] = "Esenhigh";
$lastnames[] = "Everingham";
$lastnames[] = "Ezzy";
$lastnames[] = "Fahy";
$lastnames[] = "Fairweather";
$lastnames[] = "Fannin";
$lastnames[] = "Farman";
$lastnames[] = "Farrow";
$lastnames[] = "Feathers";
$lastnames[] = "Fellingham";
$lastnames[] = "Ferguson";
$lastnames[] = "Fergusson";
$lastnames[] = "Ferris";
$lastnames[] = "Fesenmeyer";
$lastnames[] = "Fields";
$lastnames[] = "Fischer";
$lastnames[] = "Fisher";
$lastnames[] = "Fisk";
$lastnames[] = "Fitzpatrick";
$lastnames[] = "Flanigan";
$lastnames[] = "Fleming";
$lastnames[] = "Fletcher";
$lastnames[] = "Flight";
$lastnames[] = "Flynn";
$lastnames[] = "Forbes";
$lastnames[] = "Ford";
$lastnames[] = "Forrester";
$lastnames[] = "Fraser";
$lastnames[] = "Frazier";
$lastnames[] = "Freebody";
$lastnames[] = "Freeman";
$lastnames[] = "Fuller";
$lastnames[] = "Fulton";
$lastnames[] = "Gadby";
$lastnames[] = "Galway";
$lastnames[] = "Gardner";
$lastnames[] = "Garette";
$lastnames[] = "Gerlach";
$lastnames[] = "Gill";
$lastnames[] = "Glen";
$lastnames[] = "Godde";
$lastnames[] = "Goldspring";
$lastnames[] = "Goodall";
$lastnames[] = "Gooden";
$lastnames[] = "Goodlet";
$lastnames[] = "Gordon";
$lastnames[] = "Gowen";
$lastnames[] = "Graeme";
$lastnames[] = "Graham";
$lastnames[] = "Gray";
$lastnames[] = "Green";
$lastnames[] = "Greenhalge";
$lastnames[] = "Greenhalgh";
$lastnames[] = "Greenland";
$lastnames[] = "Greentree";
$lastnames[] = "Greenwood";
$lastnames[] = "Gregg";
$lastnames[] = "Griffiths";
$lastnames[] = "Grigg";
$lastnames[] = "Gruse";
$lastnames[] = "Gurnett";
$lastnames[] = "Guthrie";
$lastnames[] = "Hale";
$lastnames[] = "Halliday";
$lastnames[] = "Hamilton";
$lastnames[] = "Hanes";
$lastnames[] = "Hannant";
$lastnames[] = "Hanson";
$lastnames[] = "Harris";
$lastnames[] = "Harrison";
$lastnames[] = "Hay";
$lastnames[] = "Hayden";
$lastnames[] = "Hayward";
$lastnames[] = "Hazlitt";
$lastnames[] = "Healey";
$lastnames[] = "Healy";
$lastnames[] = "Hemmings";
$lastnames[] = "Henderson";
$lastnames[] = "Hennessey";
$lastnames[] = "Hennessy";
$lastnames[] = "Hetherton";
$lastnames[] = "Hilder";
$lastnames[] = "Hill";
$lastnames[] = "Hilliard";
$lastnames[] = "Hine";
$lastnames[] = "Hirst";
$lastnames[] = "Hitchman";
$lastnames[] = "Hogg";
$lastnames[] = "Holland";
$lastnames[] = "Holliday";
$lastnames[] = "Holmes";
$lastnames[] = "Hooper";
$lastnames[] = "Hoskisson";
$lastnames[] = "Hubbard";
$lastnames[] = "Hull";
$lastnames[] = "Hurlstone";
$lastnames[] = "Imray";
$lastnames[] = "Ingram";
$lastnames[] = "Ironside";
$lastnames[] = "Irving";
$lastnames[] = "Izzard";
$lastnames[] = "Jackson";
$lastnames[] = "Jaques";
$lastnames[] = "Jarvis";
$lastnames[] = "Jenkins";
$lastnames[] = "Johnson";
$lastnames[] = "Johnston";
$lastnames[] = "Johnstone";
$lastnames[] = "Jones";
$lastnames[] = "Jose";
$lastnames[] = "Joyce";
$lastnames[] = "Kapp";
$lastnames[] = "Kay";
$lastnames[] = "Keast";
$lastnames[] = "Kelly";
$lastnames[] = "Kemp";
$lastnames[] = "Kennedy";
$lastnames[] = "Keogh";
$lastnames[] = "Kerr";
$lastnames[] = "Kingsmill";
$lastnames[] = "Kingston";
$lastnames[] = "Kirk";
$lastnames[] = "Knapp";
$lastnames[] = "Knight";
$lastnames[] = "Lambshaw";
$lastnames[] = "Lampe";
$lastnames[] = "Lampshire";
$lastnames[] = "Lancaster";
$lastnames[] = "Landale";
$lastnames[] = "Lanpenche";
$lastnames[] = "Lantry";
$lastnames[] = "Laurenson";
$lastnames[] = "Laurie";
$lastnames[] = "Lean";
$lastnames[] = "Lee";
$lastnames[] = "Letcher";
$lastnames[] = "Lillis";
$lastnames[] = "Lindon";
$lastnames[] = "Lindsay";
$lastnames[] = "Linebarger";
$lastnames[] = "Livingstone";
$lastnames[] = "Lloyd";
$lastnames[] = "Lloyd-Jones";
$lastnames[] = "Logan";
$lastnames[] = "Lord";
$lastnames[] = "Lowe";
$lastnames[] = "Luke";
$lastnames[] = "Lyle";
$lastnames[] = "Lynan";
$lastnames[] = "Lyons";
$lastnames[] = "MacKeller";
$lastnames[] = "Macallister";
$lastnames[] = "Machin";
$lastnames[] = "Macintosh";
$lastnames[] = "Mackay";
$lastnames[] = "Mackie";
$lastnames[] = "Maher";
$lastnames[] = "Maloney";
$lastnames[] = "Mamby";
$lastnames[] = "Manning";
$lastnames[] = "Martin";
$lastnames[] = "Mason";
$lastnames[] = "Masters";
$lastnames[] = "Matchett";
$lastnames[] = "McAlpine";
$lastnames[] = "McBride";
$lastnames[] = "McCracken";
$lastnames[] = "McCurly";
$lastnames[] = "McDonald";
$lastnames[] = "McEachern";
$lastnames[] = "McFarland";
$lastnames[] = "McGowan";
$lastnames[] = "McGrath";
$lastnames[] = "McGregor";
$lastnames[] = "McIver";
$lastnames[] = "McKay";
$lastnames[] = "McKechnie";
$lastnames[] = "McKenzie";
$lastnames[] = "McKeon";
$lastnames[] = "McKinnon";
$lastnames[] = "McLaren";
$lastnames[] = "McLelland";
$lastnames[] = "McLeod";
$lastnames[] = "McMichael";
$lastnames[] = "McMullen";
$lastnames[] = "McNamara";
$lastnames[] = "McNeill";
$lastnames[] = "McRae";
$lastnames[] = "McRorie";
$lastnames[] = "Meggs";
$lastnames[] = "Melelen";
$lastnames[] = "Mellish";
$lastnames[] = "Mergin";
$lastnames[] = "Meyers";
$lastnames[] = "Mighell";
$lastnames[] = "Miles";
$lastnames[] = "Miller";
$lastnames[] = "Mills";
$lastnames[] = "Milne";
$lastnames[] = "Molesworth";
$lastnames[] = "Montgomery";
$lastnames[] = "Moore";
$lastnames[] = "Morgan";
$lastnames[] = "Morin";
$lastnames[] = "Morley";
$lastnames[] = "Morris";
$lastnames[] = "Morrison";
$lastnames[] = "Morrow";
$lastnames[] = "Morton";
$lastnames[] = "Mowsar";
$lastnames[] = "Muir";
$lastnames[] = "Muller";
$lastnames[] = "Mundell";
$lastnames[] = "Munro";
$lastnames[] = "Murphy";
$lastnames[] = "Murray";
$lastnames[] = "Mutton";
$lastnames[] = "Nash";
$lastnames[] = "Neave";
$lastnames[] = "Neily";
$lastnames[] = "Neithercut";
$lastnames[] = "Newbury";
$lastnames[] = "Neylon";
$lastnames[] = "Normile";
$lastnames[] = "Normoyle";
$lastnames[] = "Norris";
$lastnames[] = "North";
$lastnames[] = "Notley";
$lastnames[] = "O'Brien";
$lastnames[] = "O'Brien";
$lastnames[] = "O'Brien";
$lastnames[] = "Ochs";
$lastnames[] = "Old";
$lastnames[] = "Oliver";
$lastnames[] = "Ormsby";
$lastnames[] = "Osborne";
$lastnames[] = "Outten";
$lastnames[] = "Owen";
$lastnames[] = "Owens";
$lastnames[] = "Oxenbridge";
$lastnames[] = "Palazzi";
$lastnames[] = "Patterson";
$lastnames[] = "Payne";
$lastnames[] = "Peacock";
$lastnames[] = "Pedlar";
$lastnames[] = "Pendrick";
$lastnames[] = "Penfold";
$lastnames[] = "Penrose";
$lastnames[] = "Perry";
$lastnames[] = "Peterson";
$lastnames[] = "Phelan";
$lastnames[] = "Phillips";
$lastnames[] = "Pickering";
$lastnames[] = "Pigg";
$lastnames[] = "Piggott";
$lastnames[] = "Pitt";
$lastnames[] = "Plater";
$lastnames[] = "Plunkett";
$lastnames[] = "Pole";
$lastnames[] = "Polglase";
$lastnames[] = "Porter";
$lastnames[] = "Powell";
$lastnames[] = "Power";
$lastnames[] = "Pratt";
$lastnames[] = "Primmer";
$lastnames[] = "Prothero";
$lastnames[] = "Provis";
$lastnames[] = "Prowse";
$lastnames[] = "Prynn";
$lastnames[] = "Puckley";
$lastnames[] = "Purdon";
$lastnames[] = "Pye";
$lastnames[] = "Quartly";
$lastnames[] = "Quessey";
$lastnames[] = "Quirk";
$lastnames[] = "Ramsay";
$lastnames[] = "Ramsden";
$lastnames[] = "Rashley";
$lastnames[] = "Reid";
$lastnames[] = "Rendle";
$lastnames[] = "Renfree";
$lastnames[] = "Reynolds";
$lastnames[] = "Richardson";
$lastnames[] = "Rigby";
$lastnames[] = "Rigelsford";
$lastnames[] = "Ritch";
$lastnames[] = "Robards";
$lastnames[] = "Roberts";
$lastnames[] = "Robertson";
$lastnames[] = "Robinson";
$lastnames[] = "Rogers";
$lastnames[] = "Rose";
$lastnames[] = "Ross";
$lastnames[] = "Rowe";
$lastnames[] = "Rudder";
$lastnames[] = "Ryberg";
$lastnames[] = "Sampson";
$lastnames[] = "Sauer";
$lastnames[] = "Saunders";
$lastnames[] = "Savage";
$lastnames[] = "Schneider";
$lastnames[] = "Schwind";
$lastnames[] = "Scottow";
$lastnames[] = "Scriven";
$lastnames[] = "Scurrah";
$lastnames[] = "Sears";
$lastnames[] = "Seccomb";
$lastnames[] = "Secomb";
$lastnames[] = "Sergeant";
$lastnames[] = "Shaw";
$lastnames[] = "Sheather";
$lastnames[] = "Shekleton";
$lastnames[] = "Shepherd";
$lastnames[] = "Siddall";
$lastnames[] = "Small";
$lastnames[] = "Smart";
$lastnames[] = "Smith";
$lastnames[] = "Smyth";
$lastnames[] = "Snedden";
$lastnames[] = "Snoad";
$lastnames[] = "Snowden";
$lastnames[] = "Solomon";
$lastnames[] = "Spalding";
$lastnames[] = "Spenceley";
$lastnames[] = "Spry";
$lastnames[] = "Stanford";
$lastnames[] = "Starr";
$lastnames[] = "Steed";
$lastnames[] = "Stephens";
$lastnames[] = "Stokes";
$lastnames[] = "Stonham";
$lastnames[] = "Street";
$lastnames[] = "Suart";
$lastnames[] = "Such";
$lastnames[] = "Sullivan";
$lastnames[] = "Tamlyn";
$lastnames[] = "Taylor";
$lastnames[] = "Thew";
$lastnames[] = "Thompson";
$lastnames[] = "Thorpe";
$lastnames[] = "Thurling";
$lastnames[] = "Tiedemann";
$lastnames[] = "Tindall";
$lastnames[] = "Toohey";
$lastnames[] = "Toope";
$lastnames[] = "Toweroff";
$lastnames[] = "Townsend";
$lastnames[] = "Tupper";
$lastnames[] = "Turner";
$lastnames[] = "Turnham";
$lastnames[] = "Unicomb";
$lastnames[] = "Upton";
$lastnames[] = "Vincent";
$lastnames[] = "Walker";
$lastnames[] = "Wall";
$lastnames[] = "Wallace";
$lastnames[] = "Wallbridge";
$lastnames[] = "Waller";
$lastnames[] = "Wallis";
$lastnames[] = "Wardropp";
$lastnames[] = "Washington";
$lastnames[] = "Watson";
$lastnames[] = "Watts";
$lastnames[] = "Wells";
$lastnames[] = "Welsh";
$lastnames[] = "West";
$lastnames[] = "Whaley";
$lastnames[] = "Wheeler";
$lastnames[] = "White";
$lastnames[] = "Whiteman";
$lastnames[] = "Wicks";
$lastnames[] = "Wild";
$lastnames[] = "Wilkins";
$lastnames[] = "Wilkinson";
$lastnames[] = "Williams";
$lastnames[] = "Willsmore";
$lastnames[] = "Wilson";
$lastnames[] = "Winshuttle";
$lastnames[] = "Wise";
$lastnames[] = "Wood";
$lastnames[] = "Woodhall";
$lastnames[] = "Woodlands";
$lastnames[] = "Wyburn";
$lastnames[] = "Yellop";
$lastnames[] = "Youle";

// Firstnames

$names[] = "Adam";
$names[] = "Alan";
$names[] = "Albert";
$names[] = "Alfonso";
$names[] = "Afonso";
$names[] = "Alphonso";
$names[] = "Alexander";
$names[] = "Alexandre";
$names[] = "Alessandro";
$names[] = "Aleksander";
$names[] = "Alessandra";
$names[] = "Alexandra";
$names[] = "Alexa";
$names[] = "Alexius";
$names[] = "Alice";
$names[] = "Alison";
$names[] = "Allison";
$names[] = "Alyson";
$names[] = "Anders";
$names[] = "Andre";
$names[] = "Andrea";
$names[] = "Andreas";
$names[] = "Andrew";
$names[] = "Ann";
$names[] = "Anne";
$names[] = "Anthony";
$names[] = "Antoine";
$names[] = "Ara";
$names[] = "Ashod";
$names[] = "Astrid";
$names[] = "Barry";
$names[] = "Benjamin";
$names[] = "Bernard";
$names[] = "Bethany";
$names[] = "Betty";
$names[] = "Burt";
$names[] = "Carol";
$names[] = "Carrie";
$names[] = "Charles";
$names[] = "Carl";
$names[] = "Karl";
$names[] = "Carlos";
$names[] = "Carlo";
$names[] = "Constantine";
$names[] = "Cyrus";
$names[] = "Cinzia";
$names[] = "Dale";
$names[] = "Daniel";
$names[] = "Darren";
$names[] = "David";
$names[] = "Derek";
$names[] = "Dora";
$names[] = "Duncan";
$names[] = "Dylan";
$names[] = "Edward";
$names[] = "Edouard";
$names[] = "Edoardo";
$names[] = "Edwin";
$names[] = "Egbert";
$names[] = "Elizabeth";
$names[] = "Elisabeth";
$names[] = "Elisabetta";
$names[] = "Eochaid";
$names[] = "Eve";
$names[] = "Ferdinand";
$names[] = "Francis";
$names[] = "Frank";
$names[] = "Frederick";
$names[] = "Friedrich";
$names[] = "Federico";
$names[] = "Gareth";
$names[] = "Gary";
$names[] = "Geoffrey";
$names[] = "George";
$names[] = "Georg";
$names[] = "Georges";
$names[] = "Giorgio";
$names[] = "Graham";
$names[] = "Grant";
$names[] = "Guy";
$names[] = "Golnaz";
$names[] = "Harrison";
$names[] = "Harold";
$names[] = "Henry";
$names[] = "Heinrich";
$names[] = "Henri";
$names[] = "Enrico";
$names[] = "Ian";
$names[] = "Iain";
$names[] = "Isaac";
$names[] = "James";
$names[] = "Jenny";
$names[] = "Jocelyn";
$names[] = "John";
$names[] = "Johannes";
$names[] = "Jean";
$names[] = "Giovanni";
$names[] = "Joshua";
$names[] = "Josh";
$names[] = "Julia";
$names[] = "Julie";
$names[] = "Kamal";
$names[] = "Kamyar";
$names[] = "Kara";
$names[] = "Karen";
$names[] = "Katie";
$names[] = "Kenneth";
$names[] = "Kirk";
$names[] = "Lea";
$names[] = "Leah";
$names[] = "Leanne";
$names[] = "Lee";
$names[] = "Leigh";
$names[] = "Leslie";
$names[] = "Les";
$names[] = "Lester";
$names[] = "Liam";
$names[] = "Lorna";
$names[] = "Lorne";
$names[] = "Louis";
$names[] = "Ludwig";
$names[] = "Luigi";
$names[] = "Marcy";
$names[] = "Marietta";
$names[] = "Mark";
$names[] = "Martin";
$names[] = "Marvin";
$names[] = "Mary";
$names[] = "Marie";
$names[] = "Maria";
$names[] = "Matthew";
$names[] = "Matt";
$names[] = "Maureen";
$names[] = "Michael";
$names[] = "Mike";
$names[] = "Mickey";
$names[] = "Mohammed";
$names[] = "Mina";
$names[] = "Nadine";
$names[] = "Narcissus";
$names[] = "Natalie";
$names[] = "Neil";
$names[] = "Nestor";
$names[] = "Nicholas";
$names[] = "Nigel";
$names[] = "Oliver";
$names[] = "Olivia";
$names[] = "Oscar";
$names[] = "Osama";
$names[] = "Owen";
$names[] = "Pamela";
$names[] = "Patrick";
$names[] = "Patricia";
$names[] = "Patty";
$names[] = "Penelope";
$names[] = "Penny";
$names[] = "Peter";
$names[] = "Philip";
$names[] = "Philippe";
$names[] = "Filippo";
$names[] = "Quentin";
$names[] = "Rachel";
$names[] = "Raymond";
$names[] = "Robert";
$names[] = "Roberto";
$names[] = "Ryan";
$names[] = "Simon";
$names[] = "Simone";
$names[] = "Sophia";
$names[] = "Sophie";
$names[] = "Stephen";
$names[] = "Steven";
$names[] = "Susanne";
$names[] = "Theodore";
$names[] = "Thomas";
$names[] = "Thurgood";
$names[] = "Thurstan";
$names[] = "Tyson";
$names[] = "Uriah";
$names[] = "Veronica";
$names[] = "Victor";
$names[] = "Victoria";
$names[] = "Vincent";
$names[] = "Viola";
$names[] = "Venus-gonzalez";
$names[] = "William";
$names[] = "Wilhelm";
$names[] = "Willem";
$names[] = "Guillaume";
$names[] = "Guglielmo";
$names[] = "Victor";
$names[] = "Wieslawa";
$names[] = "Xavier";
$names[] = "Xena";
$names[] = "Yasmin";
$names[] = "Yoko";
$names[] = "Yekaterina";
$names[] = "Zacharia";
$names[] = "Zara";
$names[] = "Zahra";

// Host names

$nodenames[] = "JOOLS";
$nodenames[] = "JOPS";
$nodenames[] = "STOO";
$nodenames[] = "RJ";
$nodenames[] = "UBIK";
$nodenames[] = "CJ";
$nodenames[] = "CHRIS";
$nodenames[] = "PETE";
$nodenames[] = "TADGER";
$nodenames[] = "HECTOR";
$nodenames[] = "ELROY";
$nodenames[] = "SOFTY";
$nodenames[] = "MAC";
$nodenames[] = "BOMBER";
$nodenames[] = "STAN";
$nodenames[] = "TOSH";
$nodenames[] = "BRAINS";
$nodenames[] = "NORM";
$nodenames[] = "BUSTER";
$nodenames[] = "SPIKE";
$nodenames[] = "BROWNY";
$nodenames[] = "MURPHY";
$nodenames[] = "KILLER";
$nodenames[] = "ABDUL";
$nodenames[] = "SPOTTY";
$nodenames[] = "GOOFY";
$nodenames[] = "DONALD";
$nodenames[] = "WINDY";
$nodenames[] = "NIFTA";
$nodenames[] = "DENZIL";
$nodenames[] = "CEDRIC";
$nodenames[] = "ALF";
$nodenames[] = "MARTY";
$nodenames[] = "CECIL";
$nodenames[] = "WALLY";
$nodenames[] = "PERVY";
$nodenames[] = "JASON";
$nodenames[] = "ROY";
$nodenames[] = "PEEWEE";
$nodenames[] = "ARNIE";
$nodenames[] = "LOFTY";
$nodenames[] = "TUBBY";
$nodenames[] = "PORKY";
$nodenames[] = "NORRIS";
$nodenames[] = "BUGSY";
$nodenames[] = "GREG";
$nodenames[] = "GUS";
$nodenames[] = "GINGER";
$nodenames[] = "EDDY";
$nodenames[] = "STEVE";
$nodenames[] = "HUGO";
$nodenames[] = "ZIPPY";
$nodenames[] = "SONNY";
$nodenames[] = "WILLY";
$nodenames[] = "MARIO";
$nodenames[] = "LUIGI";
$nodenames[] = "BO";
$nodenames[] = "JOHAN";
$nodenames[] = "COLIN";
$nodenames[] = "QUEENY";
$nodenames[] = "MORGAN";
$nodenames[] = "REG";
$nodenames[] = "PETER";
$nodenames[] = "BRETT";
$nodenames[] = "MATT";
$nodenames[] = "VIC";
$nodenames[] = "HUT";
$nodenames[] = "BUD";
$nodenames[] = "BRAD";
$nodenames[] = "ASHLEY";
$nodenames[] = "LES";
$nodenames[] = "REX";
$nodenames[] = "LOUIS";
$nodenames[] = "PEDRO";
$nodenames[] = "MARCO";
$nodenames[] = "LEON";
$nodenames[] = "ALI";
$nodenames[] = "TYSON";
$nodenames[] = "TIGER";
$nodenames[] = "FRANK";
$nodenames[] = "REUBEN";
$nodenames[] = "LEYTON";
$nodenames[] = "JOSH";
$nodenames[] = "JUDAS";
$nodenames[] = "AJ";
$nodenames[] = "LEX";
$nodenames[] = "BUTCH";
$nodenames[] = "BISON";
$nodenames[] = "GARY";
$nodenames[] = "LUTHER";
$nodenames[] = "KERMIT";
$nodenames[] = "BRIAN";
$nodenames[] = "RAY";
$nodenames[] = "FREAK";
$nodenames[] = "LEROY";
$nodenames[] = "LEE";
$nodenames[] = "BANJO";
$nodenames[] = "BEAKER";
$nodenames[] = "BASIL";
$nodenames[] = "BONZO";
$nodenames[] = "KELVIN";
$nodenames[] = "RONNIE";
$nodenames[] = "RUPERT";
$nodenames[] = "ROO";
$nodenames[] = "DAN";
$nodenames[] = "JIMMY";
$nodenames[] = "RONNIE";
$nodenames[] = "BOB";
$nodenames[] = "DON";
$nodenames[] = "TOMMY";
$nodenames[] = "EDDIE";
$nodenames[] = "OZZY";
$nodenames[] = "MARK";
$nodenames[] = "PADDY";
$nodenames[] = "ARNOLD";
$nodenames[] = "TONY";
$nodenames[] = "TEDDY";
$nodenames[] = "DOM";
$nodenames[] = "THEO";
$nodenames[] = "MARTIN";
$nodenames[] = "CHUNKY";
$nodenames[] = "JON";
$nodenames[] = "BEN";
$nodenames[] = "GIRLY";
$nodenames[] = "JULIAN";
$nodenames[] = "GARY";
$nodenames[] = "PIZZA";
$nodenames[] = "MARK";
$nodenames[] = "CIARAN";
$nodenames[] = "JOCK";
$nodenames[] = "GRAVY";
$nodenames[] = "TRENDY";
$nodenames[] = "NEIL";
$nodenames[] = "DEREK";
$nodenames[] = "ED";
$nodenames[] = "STEVE";
$nodenames[] = "BIFF";
$nodenames[] = "STEVE";
$nodenames[] = "PAUL";
$nodenames[] = "STUART";
$nodenames[] = "RANDY";
$nodenames[] = "LORETA";
$nodenames[] = "SUZIE";
$nodenames[] = "PUMPY";
$nodenames[] = "URMER";
$nodenames[] = "ROGER";
$nodenames[] = "PUSSY";
$nodenames[] = "MEAT";
$nodenames[] = "BEEFY";
$nodenames[] = "HARRY";
$nodenames[] = "TINY";
$nodenames[] = "HOWARD";
$nodenames[] = "MORRIS";
$nodenames[] = "THOR";
$nodenames[] = "REV";
$nodenames[] = "DUKE";
$nodenames[] = "WILLY";
$nodenames[] = "MICKY";
$nodenames[] = "CHAS";
$nodenames[] = "MELONY";
$nodenames[] = "CRAIG";
$nodenames[] = "SIDNEY";
$nodenames[] = "PARSON";
$nodenames[] = "ROWAN";
$nodenames[] = "SMELLY";
$nodenames[] = "DOK";
$nodenames[] = "STEW";
$nodenames[] = "DONALD";
$nodenames[] = "ADRIAN";
$nodenames[] = "PAT";
$nodenames[] = "ICEMAN";
$nodenames[] = "GOOSE";
$nodenames[] = "DIPPY";
$nodenames[] = "VIV";
$nodenames[] = "FAGS";
$nodenames[] = "BUNTY";
$nodenames[] = "NOEL";
$nodenames[] = "BONO";
$nodenames[] = "EDGE";
$nodenames[] = "ROBBIE";
$nodenames[] = "SEAN";
$nodenames[] = "MILES";
$nodenames[] = "JIMI";
$nodenames[] = "GORDON";
$nodenames[] = "VAL";
$nodenames[] = "HOBO";
$nodenames[] = "FUNGUS";
$nodenames[] = "TOILET";
$nodenames[] = "LAMPY";
$nodenames[] = "MARCUS";
$nodenames[] = "PELE";
$nodenames[] = "HUBERT";
$nodenames[] = "JAMES";
$nodenames[] = "TIM";
$nodenames[] = "SAUL";
$nodenames[] = "ANDY";
$nodenames[] = "ALF";
$nodenames[] = "SILKY";
$nodenames[] = "SIMON";
$nodenames[] = "HANDY";
$nodenames[] = "SID";
$nodenames[] = "GEORGE";
$nodenames[] = "JOFF";
$nodenames[] = "BARRY";
$nodenames[] = "DICK";
$nodenames[] = "GIL";
$nodenames[] = "NICK";
$nodenames[] = "TED";
$nodenames[] = "PHIL";
$nodenames[] = "WOODY";
$nodenames[] = "WYNN";
$nodenames[] = "ALAN";
$nodenames[] = "PIP";
$nodenames[] = "MICKEY";
$nodenames[] = "JUSTIN";
$nodenames[] = "KARL";
$nodenames[] = "MADDOG";
$nodenames[] = "HORACE";
$nodenames[] = "HAROLD";
$nodenames[] = "GAZZA";
$nodenames[] = "SPIV";
$nodenames[] = "FOXY";
$nodenames[] = "NED";
$nodenames[] = "BAZIL";
$nodenames[] = "OLIVER";
$nodenames[] = "RETT";
$nodenames[] = "SCOT";
$nodenames[] = "DARREN";
$nodenames[] = "EDWIN";
$nodenames[] = "MOSES";
$nodenames[] = "NOAH";
$nodenames[] = "SETH";
$nodenames[] = "BUDDAH";
$nodenames[] = "MARY";
$nodenames[] = "PILOT";
$nodenames[] = "MCBETH";
$nodenames[] = "MCDUFF";
$nodenames[] = "BELLY";
$nodenames[] = "MATHEW";
$nodenames[] = "MARK";
$nodenames[] = "LUKE";
$nodenames[] = "JOHN";
$nodenames[] = "ASLAM";
$nodenames[] = "HAM";
$nodenames[] = "SHEM";
$nodenames[] = "JOSHUA";
$nodenames[] = "JACOB";
$nodenames[] = "ESAW";
$nodenames[] = "OMAR";
$nodenames[] = "SAUL";
$nodenames[] = "ENOCH";
$nodenames[] = "OBADIA";
$nodenames[] = "DANIEL";
$nodenames[] = "SAMUEL";
$nodenames[] = "BEN";
$nodenames[] = "ROBBO";
$nodenames[] = "JOEBED";
$nodenames[] = "ISMAEL";
$nodenames[] = "ISREAL";
$nodenames[] = "ISABEL";
$nodenames[] = "ISARAT";
$nodenames[] = "MONK";
$nodenames[] = "BLIP";
$nodenames[] = "BACON";
$nodenames[] = "DANUBE";
$nodenames[] = "FRIEND";
$nodenames[] = "DARRYL";
$nodenames[] = "IZZY";
$nodenames[] = "CROSBY";
$nodenames[] = "STILLS";
$nodenames[] = "NASH";
$nodenames[] = "YOUNG";
$nodenames[] = "CHEESE";
$nodenames[] = "SALAMI";
$nodenames[] = "PRAWN";
$nodenames[] = "RADISH";
$nodenames[] = "EGBERT";
$nodenames[] = "EDWY";
$nodenames[] = "EDGAR";
$nodenames[] = "EDWIN";
$nodenames[] = "EDRED";
$nodenames[] = "EGGPIE";
$nodenames[] = "BROS";
$nodenames[] = "SONIC";
$nodenames[] = "ZIGGY";
$nodenames[] = "ALFRED";
$nodenames[] = "SIGGY";
$nodenames[] = "HILDA";
$nodenames[] = "SNELL";
$nodenames[] = "SPARKS";
$nodenames[] = "SPOOK";
$nodenames[] = "TOPCAT";
$nodenames[] = "BENNY";
$nodenames[] = "DIBBLE";
$nodenames[] = "BENKER";
$nodenames[] = "DOSEY";
$nodenames[] = "BEAKY";
$nodenames[] = "JOIST";
$nodenames[] = "PIVOT";
$nodenames[] = "TREE";
$nodenames[] = "BUSH";
$nodenames[] = "GRASS";
$nodenames[] = "SEEDY";
$nodenames[] = "TIN";
$nodenames[] = "ROLLO";
$nodenames[] = "ZIPPO";
$nodenames[] = "NANCY";
$nodenames[] = "LARRY";
$nodenames[] = "IGGY";
$nodenames[] = "NIGEL";
$nodenames[] = "JAMIE";
$nodenames[] = "JESSE";
$nodenames[] = "LEO";
$nodenames[] = "VIRGO";
$nodenames[] = "GARTH";
$nodenames[] = "FIDEL";
$nodenames[] = "IDI";
$nodenames[] = "CHE";
$nodenames[] = "KIRK";
$nodenames[] = "SPOCK";
$nodenames[] = "MACCOY";
$nodenames[] = "CHEKOV";
$nodenames[] = "UHURA";
$nodenames[] = "BONES";
$nodenames[] = "VULCAN";
$nodenames[] = "FESTER";
$nodenames[] = "JETHRO";
$nodenames[] = "JIMBOB";
$nodenames[] = "DECLAN";
$nodenames[] = "DALEK";
$nodenames[] = "HICKEY";
$nodenames[] = "CHOCCO";
$nodenames[] = "GOCH";
$nodenames[] = "PABLO";
$nodenames[] = "RENOIR";
$nodenames[] = "ROLF";
$nodenames[] = "DALI";
$nodenames[] = "MONET";
$nodenames[] = "MANET";
$nodenames[] = "GAUGIN";
$nodenames[] = "CHAGAL";
$nodenames[] = "KID";
$nodenames[] = "HULLY";
$nodenames[] = "ROBERT";
$nodenames[] = "PIERS";
$nodenames[] = "RAITH";
$nodenames[] = "JEEVES";
$nodenames[] = "PASTER";
$nodenames[] = "ADOLF";
$nodenames[] = "DEITER";
$nodenames[] = "DENI";
$nodenames[] = "ZARK";
$nodenames[] = "WIZKID";
$nodenames[] = "WIZARD";
$nodenames[] = "IAIN";
$nodenames[] = "KITTEN";
$nodenames[] = "GONNER";
$nodenames[] = "WASTER";
$nodenames[] = "LOSER";
$nodenames[] = "FODDER";
$nodenames[] = "CYCLOP";
$nodenames[] = "STORM";
$nodenames[] = "COLOSSUS";
$nodenames[] = "WOLVERINE";
$nodenames[] = "ROGUE";
$nodenames[] = "BEAST";
$nodenames[] = "PHONIX";
$nodenames[] = "MORPH";
$nodenames[] = "BAMSHE";
$nodenames[] = "ANGEL";
$nodenames[] = "DAZZLER";
$nodenames[] = "JUBILEE";
$nodenames[] = "GAMBIT";
$nodenames[] = "PUNISHER";
$nodenames[] = "IRONMAN";
$nodenames[] = "HULK";
$nodenames[] = "SPIDERMAN";
$nodenames[] = "THOR";
$nodenames[] = "OCTOPUS";
$nodenames[] = "VENOM";
$nodenames[] = "REDSKULL";
$nodenames[] = "SCORPION";
$nodenames[] = "OMEGARED";
$nodenames[] = "RAMBO";
$nodenames[] = "ROCKY";
$nodenames[] = "COMMANDO";
$nodenames[] = "PREDATOR";
$nodenames[] = "BLADE";
$nodenames[] = "CYCL0P";
$nodenames[] = "ST0RM";
$nodenames[] = "C0LOSSUS";
$nodenames[] = "W0LVERINE";
$nodenames[] = "R0GUE";
$nodenames[] = "B3AST";
$nodenames[] = "PH0NIX";
$nodenames[] = "M0RPH";
$nodenames[] = "B4MSHE";
$nodenames[] = "ANG3L";
$nodenames[] = "D4ZZLER";
$nodenames[] = "JUB1LEE";
$nodenames[] = "G4MBIT";
$nodenames[] = "PUN1SHER";
$nodenames[] = "IR0NMAN";
$nodenames[] = "SP1DERMAN";
$nodenames[] = "TH0R";
$nodenames[] = "OC7OPUS";
$nodenames[] = "V3NOM";
$nodenames[] = "R3DSKULL";
$nodenames[] = "SC0RPION";
$nodenames[] = "OM3GARED";
$nodenames[] = "R4MBO";
$nodenames[] = "R0CKY";
$nodenames[] = "C0MMANDO";
$nodenames[] = "PR3DATOR";
$nodenames[] = "BL4DE";
$nodenames[] = "COL0SSUS";
$nodenames[] = "WOLV3RINE";
$nodenames[] = "BE4ST";
$nodenames[] = "PHON1X";
$nodenames[] = "BAM5HE";
$nodenames[] = "DA22LER";
$nodenames[] = "JUBIL3E";
$nodenames[] = "GAMB1T";
$nodenames[] = "PUNI5HER";
$nodenames[] = "IRONM4N";
$nodenames[] = "SPID3RMAN";
$nodenames[] = "OCT0PUS";
$nodenames[] = "VEN0M";
$nodenames[] = "RED5KULL";
$nodenames[] = "SCORP1ON";
$nodenames[] = "OMEG4RED";
$nodenames[] = "COMM4NDO";
$nodenames[] = "PRED4TOR";
$nodenames[] = "COLO55US";
$nodenames[] = "WOLVER1NE";
$nodenames[] = "BEA5T";
$nodenames[] = "PH0N1X";
$nodenames[] = "B4M5HE";
$nodenames[] = "DAZZL3R";
$nodenames[] = "JUB1L3E";
$nodenames[] = "G4MB1T";
$nodenames[] = "PUNISH3R";
$nodenames[] = "IR0NM4N";
$nodenames[] = "SPIDERM4N";
$nodenames[] = "OC70PUS";
$nodenames[] = "V3N0M";
$nodenames[] = "R3D5KULL";
$nodenames[] = "SCORPI0N";
$nodenames[] = "OMEGAR3D";
$nodenames[] = "C0MM4NDO";
$nodenames[] = "PREDA7OR";
$nodenames[] = "C0L0SSUS";
$nodenames[] = "W0LV3RINE";
$nodenames[] = "B34ST";
$nodenames[] = "D422LER";
$nodenames[] = "PUN15HER";
$nodenames[] = "SP1D3RMAN";
$nodenames[] = "SC0RP1ON";
$nodenames[] = "OM3G4RED";
$nodenames[] = "PREDAT0R";
$nodenames[] = "C0LO55US";
$nodenames[] = "W0LVER1NE";
$nodenames[] = "B3A5T";
$nodenames[] = "D4ZZL3R";
$nodenames[] = "PUN1SH3R";
$nodenames[] = "SP1DERM4N";
$nodenames[] = "SC0RPI0N";
$nodenames[] = "OM3GAR3D";
$nodenames[] = "PR3D4TOR";
$nodenames[] = "COL055US";
$nodenames[] = "WOLV3R1NE";
$nodenames[] = "BE45T";
$nodenames[] = "DA22L3R";
$nodenames[] = "PUNI5H3R";
$nodenames[] = "SPID3RM4N";
$nodenames[] = "SCORP10N";
$nodenames[] = "OMEG4R3D";
$nodenames[] = "PR3DA7OR";
$nodenames[] = "COL055US";
$nodenames[] = "W0LV3R1NE";
$nodenames[] = "B345T";
$nodenames[] = "D422L3R";
$nodenames[] = "PUN15H3R";
$nodenames[] = "SP1D3RM4N";
$nodenames[] = "SC0RP10N";
$nodenames[] = "OM3G4R3D";
$nodenames[] = "PR3DAT0R";
$nodenames[] = "PRED47OR";
$nodenames[] = "PRED4T0R";
$nodenames[] = "PRED470R";
$nodenames[] = "PR3D47OR";
$nodenames[] = "PR3DA70R";
$nodenames[] = "PR3D4T0R";
$nodenames[] = "PR3D470R";
$nodenames[] = "ACHILLES";
$nodenames[] = "ACIS";
$nodenames[] = "ADMET";
$nodenames[] = "ADONIS";
$nodenames[] = "AFRODYTA";
$nodenames[] = "AGAMEMNON";
$nodenames[] = "AGAWE";
$nodenames[] = "AJAKOS";
$nodenames[] = "AJAKS";
$nodenames[] = "AKRIZJOS";
$nodenames[] = "ABAS";
$nodenames[] = "AKTEON";
$nodenames[] = "AKWILON";
$nodenames[] = "ALKESTIS";
$nodenames[] = "ALKINOOS";
$nodenames[] = "ALKMENA";
$nodenames[] = "ALKMEON";
$nodenames[] = "ALTEJA";
$nodenames[] = "ALMATEA";
$nodenames[] = "AMFIARAAS";
$nodenames[] = "AMFION";
$nodenames[] = "AMFIRON";
$nodenames[] = "AMFRYTA";
$nodenames[] = "AMOR";
$nodenames[] = "ANCHIZES";
$nodenames[] = "ANDROKLES";
$nodenames[] = "ANDROMEDA";
$nodenames[] = "ANTEUSZ";
$nodenames[] = "ANTINOOS";
$nodenames[] = "ANTIOPA";
$nodenames[] = "ANTYGONA";
$nodenames[] = "ARGOS";
$nodenames[] = "ARGUS";
$nodenames[] = "APOLLO";
$nodenames[] = "ARACHNE";
$nodenames[] = "ARES";
$nodenames[] = "ARIADNA";
$nodenames[] = "ARTEMIDA";
$nodenames[] = "ASKANIUSZ";
$nodenames[] = "ASKLEPIOS";
$nodenames[] = "ASTANAKS";
$nodenames[] = "ATLANTA";
$nodenames[] = "ATAMAS";
$nodenames[] = "ATE";
$nodenames[] = "ATENA";
$nodenames[] = "ATLAS";
$nodenames[] = "ATREUSZ";
$nodenames[] = "ATTIS";
$nodenames[] = "AUGE";
$nodenames[] = "AUGIASZ";
$nodenames[] = "AURORA";
$nodenames[] = "BACHUS";
$nodenames[] = "BAUCIS";
$nodenames[] = "BITON";
$nodenames[] = "BOREASZ";
$nodenames[] = "BRYZEJDA";
$nodenames[] = "BUZYRYS";
$nodenames[] = "CERBER";
$nodenames[] = "CENTAUR";
$nodenames[] = "CERERA";
$nodenames[] = "CHAOS";
$nodenames[] = "CHARON";
$nodenames[] = "CHARYBDA";
$nodenames[] = "CHARYTA";
$nodenames[] = "CHIMERA";
$nodenames[] = "CHIRON";
$nodenames[] = "CHLORIS";
$nodenames[] = "CHRONOS";
$nodenames[] = "CHRYZEIDA";
$nodenames[] = "CYKLOP";
$nodenames[] = "DAFNE";
$nodenames[] = "DAMOSTES";
$nodenames[] = "DANAE";
$nodenames[] = "DEDAL";
$nodenames[] = "DEIFOBOS";
$nodenames[] = "DEJANIRA";
$nodenames[] = "DEMETER";
$nodenames[] = "DEUKALION";
$nodenames[] = "DIOMEDES";
$nodenames[] = "DIONIZOS";
$nodenames[] = "DIRKE";
$nodenames[] = "DIS_PATER";
$nodenames[] = "DYDONA";
$nodenames[] = "EAK";
$nodenames[] = "ECHIDNA";
$nodenames[] = "ECHO";
$nodenames[] = "EDYP";
$nodenames[] = "EFIATLES";
$nodenames[] = "EGERIA";
$nodenames[] = "EGEUSZ";
$nodenames[] = "EGIST";
$nodenames[] = "EIRENE";
$nodenames[] = "ELAIS";
$nodenames[] = "ELEKTRA";
$nodenames[] = "ENDYMION";
$nodenames[] = "ENEASZ";
$nodenames[] = "EOL";
$nodenames[] = "EOS";
$nodenames[] = "ERATO";
$nodenames[] = "EREB";
$nodenames[] = "ERIGONE";
$nodenames[] = "ERIS";
$nodenames[] = "EROS";
$nodenames[] = "ETEOKLES";
$nodenames[] = "EUMAJOS";
$nodenames[] = "EUROPA";
$nodenames[] = "EUROS";
$nodenames[] = "EURYDYKA";
$nodenames[] = "EURKLEJA";
$nodenames[] = "EUTERPE";
$nodenames[] = "FAETON";
$nodenames[] = "FAMA";
$nodenames[] = "FAON";
$nodenames[] = "FATUM";
$nodenames[] = "FAUN";
$nodenames[] = "FAUNA";
$nodenames[] = "FEBE";
$nodenames[] = "FEBUS";
$nodenames[] = "FEDRA";
$nodenames[] = "FENIKS";
$nodenames[] = "FERONIA";
$nodenames[] = "FILEMON";
$nodenames[] = "FILOKTET";
$nodenames[] = "FILOMELA";
$nodenames[] = "FINEUS";
$nodenames[] = "FLORA";
$nodenames[] = "FOKOS";
$nodenames[] = "FORTUNA";
$nodenames[] = "FRYKSOS";
$nodenames[] = "FYLLIS";
$nodenames[] = "GAJA";
$nodenames[] = "GALATEA";
$nodenames[] = "GANIMEDES";
$nodenames[] = "GERYON";
$nodenames[] = "GLAUKOS";
$nodenames[] = "GORDIOS";
$nodenames[] = "HADES";
$nodenames[] = "HARMONIA";
$nodenames[] = "HEBE";
$nodenames[] = "HEFAJSTOS";
$nodenames[] = "HEKABE";
$nodenames[] = "HEKATE";
$nodenames[] = "HEKTOR";
$nodenames[] = "HEKUBA";
$nodenames[] = "HELENOS";
$nodenames[] = "HELIOS";
$nodenames[] = "HELLE";
$nodenames[] = "HELLEN";
$nodenames[] = "HERA";
$nodenames[] = "HERAKLES";
$nodenames[] = "HERMES";
$nodenames[] = "HERMIONA";
$nodenames[] = "HERO";
$nodenames[] = "HERSILIA";
$nodenames[] = "HESTIA";
$nodenames[] = "HEZJONE";
$nodenames[] = "HIACYNT";
$nodenames[] = "HIGIEJA";
$nodenames[] = "HYADA";
$nodenames[] = "HYMEN";
$nodenames[] = "HYPNOS";
$nodenames[] = "HYPSIPYLE";
$nodenames[] = "IDAS";
$nodenames[] = "IFIGENIA";
$nodenames[] = "IKAR";
$nodenames[] = "IKARIOS";
$nodenames[] = "IKSJON";
$nodenames[] = "INO";
$nodenames[] = "IO";
$nodenames[] = "IRIS";
$nodenames[] = "IROS";
$nodenames[] = "ISMENA";
$nodenames[] = "IZYDA";
$nodenames[] = "JANUS";
$nodenames[] = "JAZJON";
$nodenames[] = "JAZON";
$nodenames[] = "JOKASTA";
$nodenames[] = "JOWISZ";
$nodenames[] = "JUNO";
$nodenames[] = "JUNONA";
$nodenames[] = "JUPPITER";
$nodenames[] = "JUTURNA";
$nodenames[] = "KADMOS";
$nodenames[] = "KAKUS";
$nodenames[] = "KALAIS";
$nodenames[] = "KALCHAS";
$nodenames[] = "KALIOPE";
$nodenames[] = "KALIPSO";
$nodenames[] = "KAMILLA";
$nodenames[] = "KASANDRA";
$nodenames[] = "KASJOPEJA";
$nodenames[] = "KASTOR";
$nodenames[] = "KEFALOS";
$nodenames[] = "KEKROPS";
$nodenames[] = "KERKION";
$nodenames[] = "KIKLOP";
$nodenames[] = "KIRKE";
$nodenames[] = "KLEOBIS";
$nodenames[] = "KLIO";
$nodenames[] = "KORA";
$nodenames[] = "KORONIS";
$nodenames[] = "KREON";
$nodenames[] = "KREUZA";
$nodenames[] = "KRONOS";
$nodenames[] = "KUPIDO";
$nodenames[] = "KWIRYNUS";
$nodenames[] = "KYBELE";
$nodenames[] = "LABDAKOS";
$nodenames[] = "LAERTES";
$nodenames[] = "LAJOS";
$nodenames[] = "LAMIA";
$nodenames[] = "LAODAMIA";
$nodenames[] = "LAOKOON";
$nodenames[] = "LAOMEDON";
$nodenames[] = "LATONA";
$nodenames[] = "LATYNUS";
$nodenames[] = "LEANDER";
$nodenames[] = "LEDA";
$nodenames[] = "LETO";
$nodenames[] = "LEUKOTEA";
$nodenames[] = "LIBITINA";
$nodenames[] = "LIKAON";
$nodenames[] = "LIKOMEDES";
$nodenames[] = "LIKOS";
$nodenames[] = "LIKURG";
$nodenames[] = "LINOS";
$nodenames[] = "LUNA";
$nodenames[] = "LYNKEUS";
$nodenames[] = "MAJA";
$nodenames[] = "MAJRA";
$nodenames[] = "MARPESSA";
$nodenames[] = "MARS";
$nodenames[] = "MARSJASZ";
$nodenames[] = "MATER";
$nodenames[] = "MEDEA";
$nodenames[] = "MEDUZA";
$nodenames[] = "MELAMPUS";
$nodenames[] = "MELEAGER";
$nodenames[] = "MELPOMENA";
$nodenames[] = "MEMNON";
$nodenames[] = "MENELAOS";
$nodenames[] = "MENTOR";
$nodenames[] = "MERKURY";
$nodenames[] = "METIS";
$nodenames[] = "MIDAS";
$nodenames[] = "MINERWA";
$nodenames[] = "MINOS";
$nodenames[] = "MINOTAUR";
$nodenames[] = "MINYAS";
$nodenames[] = "MITRA";
$nodenames[] = "MNEMOZYNE";
$nodenames[] = "MOMOS";
$nodenames[] = "NARCYZ";
$nodenames[] = "NAUZYKAA";
$nodenames[] = "NEMEZIS";
$nodenames[] = "NEPTUN";
$nodenames[] = "NEREUS";
$nodenames[] = "NESSOS";
$nodenames[] = "NESTOR";
$nodenames[] = "NIKE";
$nodenames[] = "NIOBE";
$nodenames[] = "NOTOS";
$nodenames[] = "ODYSEUSZ";
$nodenames[] = "OINEUS";
$nodenames[] = "OINMAOS";
$nodenames[] = "OINONE";
$nodenames[] = "OINO";
$nodenames[] = "OKEANOS";
$nodenames[] = "OPS";
$nodenames[] = "OREJTYJA";
$nodenames[] = "ORESTES";
$nodenames[] = "ORFEUSZ";
$nodenames[] = "ORION";
$nodenames[] = "ORKUS";
$nodenames[] = "OTOS";
$nodenames[] = "PALAMEDES";
$nodenames[] = "PALEMON";
$nodenames[] = "PALES";
$nodenames[] = "PALLAS";
$nodenames[] = "PAN";
$nodenames[] = "PANDORA";
$nodenames[] = "PARYS";
$nodenames[] = "PASIFAE";
$nodenames[] = "PATROKLOS";
$nodenames[] = "PEGAZ";
$nodenames[] = "PEJRITOOS";
$nodenames[] = "PELEUS";
$nodenames[] = "PELOPS";
$nodenames[] = "PENELOPA";
$nodenames[] = "PENTEUSZ";
$nodenames[] = "PERSEFONA";
$nodenames[] = "PERSEUSZ";
$nodenames[] = "PIGMALION";
$nodenames[] = "PIKUS";
$nodenames[] = "PITYS";
$nodenames[] = "PLUTON";
$nodenames[] = "PLUTOS";
$nodenames[] = "POLIDOROS";
$nodenames[] = "POLIFEM";
$nodenames[] = "POLIKSENA";
$nodenames[] = "POLINIK";
$nodenames[] = "POLLUKS";
$nodenames[] = "POLYPEMON";
$nodenames[] = "POMONA";
$nodenames[] = "POSEJDON";
$nodenames[] = "PRIAM";
$nodenames[] = "PRIAP";
$nodenames[] = "PROKNE";
$nodenames[] = "PROKRIS";
$nodenames[] = "PROTEUSZ";
$nodenames[] = "PSYCHE";
$nodenames[] = "PYLADES";
$nodenames[] = "PYRAM";
$nodenames[] = "PYRRA";
$nodenames[] = "PYTIA";
$nodenames[] = "PYTON";
$nodenames[] = "REA";
$nodenames[] = "REZOS";
$nodenames[] = "ROMULUS";
$nodenames[] = "REMUS";
$nodenames[] = "SARPEDON";
$nodenames[] = "SATURN";
$nodenames[] = "SATYR";
$nodenames[] = "SCYLLA";
$nodenames[] = "SELENE";
$nodenames[] = "SEMELE";
$nodenames[] = "SFINKS";
$nodenames[] = "SILVANUS";
$nodenames[] = "SKIRON";
$nodenames[] = "SKYLLA";
$nodenames[] = "SOL";
$nodenames[] = "SPERMO";
$nodenames[] = "STENTOR";
$nodenames[] = "SYBILLA";
$nodenames[] = "SYLEN";
$nodenames[] = "SYRINKS";
$nodenames[] = "SYZYF";
$nodenames[] = "TALIA";
$nodenames[] = "TANATOS";
$nodenames[] = "TANTAL";
$nodenames[] = "TELAMON";
$nodenames[] = "TELEFOS";
$nodenames[] = "TELEGONOS";
$nodenames[] = "TELEMACH";
$nodenames[] = "TELLUS";
$nodenames[] = "TEMIDA";
$nodenames[] = "TEREUS";
$nodenames[] = "TERRA";
$nodenames[] = "TERSYTES";
$nodenames[] = "TETYDA";
$nodenames[] = "TEUKROS";
$nodenames[] = "TEZEUSZ";
$nodenames[] = "TITONOS";
$nodenames[] = "TITYOS";
$nodenames[] = "TROILAS";
$nodenames[] = "TURNUS";
$nodenames[] = "TYCHE";
$nodenames[] = "TYESTES";
$nodenames[] = "TYFON";
$nodenames[] = "TYNDAREOS";
$nodenames[] = "TYTIO";
$nodenames[] = "TYSBE";
$nodenames[] = "ULISSES";
$nodenames[] = "URANIA";
$nodenames[] = "URANOS";
$nodenames[] = "VICTORIA";
$nodenames[] = "WENUS";
$nodenames[] = "WESTA";
$nodenames[] = "WULKAN";
$nodenames[] = "ZEFIR";
$nodenames[] = "ZETES";
$nodenames[] = "ZETOS";
$nodenames[] = "ZEUS";
$nodenames[] = "ANDVARI";
$nodenames[] = "ASKR";
$nodenames[] = "AURGELMIR";
$nodenames[] = "BALDUR";
$nodenames[] = "BALDR";
$nodenames[] = "BALDER";
$nodenames[] = "BRAGI";
$nodenames[] = "EMBDA";
$nodenames[] = "FENRIR";
$nodenames[] = "FREYJA";
$nodenames[] = "FREYR";
$nodenames[] = "FRIGGA";
$nodenames[] = "FRIIA";
$nodenames[] = "HEIMDALL";
$nodenames[] = "HEL";
$nodenames[] = "HERMOD";
$nodenames[] = "HODOR";
$nodenames[] = "HEDR";
$nodenames[] = "HODER";
$nodenames[] = "IDUMA";
$nodenames[] = "IGDRASIL";
$nodenames[] = "IMIR";
$nodenames[] = "INGVI";
$nodenames[] = "JORD";
$nodenames[] = "KVASIR";
$nodenames[] = "LIF";
$nodenames[] = "MIMIR";
$nodenames[] = "NANNA";
$nodenames[] = "NIDHOGG";
$nodenames[] = "NJORD";
$nodenames[] = "NJORTH";
$nodenames[] = "ODNIR";
$nodenames[] = "ODR";
$nodenames[] = "OTHR";
$nodenames[] = "ODYN";
$nodenames[] = "SIF";
$nodenames[] = "SIGUNA";
$nodenames[] = "SIGURD";
$nodenames[] = "SKADI";
$nodenames[] = "SLEIPNIR";
$nodenames[] = "THOR";
$nodenames[] = "TYR";
$nodenames[] = "TIU";
$nodenames[] = "VALI";
$nodenames[] = "VIDAR";
$nodenames[] = "AMON";
$nodenames[] = "ANUBIS";
$nodenames[] = "ANPU";
$nodenames[] = "APIS";
$nodenames[] = "HAPE";
$nodenames[] = "HAPI";
$nodenames[] = "ATON";
$nodenames[] = "ATUM";
$nodenames[] = "BASTET";
$nodenames[] = "BAST";
$nodenames[] = "BES";
$nodenames[] = "BISU";
$nodenames[] = "BUTO";
$nodenames[] = "CHONSU";
$nodenames[] = "GEB";
$nodenames[] = "KEB";
$nodenames[] = "SEB";
$nodenames[] = "HATHOR";
$nodenames[] = "HORUS";
$nodenames[] = "HOR";
$nodenames[] = "IZYDA";
$nodenames[] = "ISIS";
$nodenames[] = "MAAT";
$nodenames[] = "MIN";
$nodenames[] = "MUT";
$nodenames[] = "NECHBET";
$nodenames[] = "NEFTYDA";
$nodenames[] = "NEIT";
$nodenames[] = "NUT";
$nodenames[] = "OZYRYS";
$nodenames[] = "PTAH";
$nodenames[] = "RE";
$nodenames[] = "RA";
$nodenames[] = "SECHMET";
$nodenames[] = "SECHTET";
$nodenames[] = "SERAPIS";
$nodenames[] = "SET";
$nodenames[] = "SOBEK";
$nodenames[] = "SZU";
$nodenames[] = "TOTH";
$nodenames[] = "ADAD";
$nodenames[] = "AN";
$nodenames[] = "BAU";
$nodenames[] = "BELIT";
$nodenames[] = "DUMUZI";
$nodenames[] = "EA";
$nodenames[] = "ENKI";
$nodenames[] = "HADAD";
$nodenames[] = "HAD";
$nodenames[] = "HADDA";
$nodenames[] = "INANNA";
$nodenames[] = "ISZKUR";
$nodenames[] = "ISZTAR";
$nodenames[] = "LAMASZTU";
$nodenames[] = "MARDUK";
$nodenames[] = "NABU";
$nodenames[] = "NANNA";
$nodenames[] = "NERGAL";
$nodenames[] = "NINHURSAG";
$nodenames[] = "NINLIL";
$nodenames[] = "NINURTA";
$nodenames[] = "NUSKU";
$nodenames[] = "SIN";
$nodenames[] = "TAMMZU";
$nodenames[] = "UTU";

// Streets

$streets[] = "Auburn Avenue";
$streets[] = "Broad Street";
$streets[] = "Capital Avenue";
$streets[] = "Courtland Street";
$streets[] = "Memorial Drive";
$streets[] = "Woodward Avenue";
$streets[] = "Monroe Avenue";
$streets[] = "Anza Street";
$streets[] = "Du Pont Street";

$phoneprefix[] = "0501";
$phoneprefix[] = "0502";
$phoneprefix[] = "0503";
$phoneprefix[] = "0504";
$phoneprefix[] = "0505";
$phoneprefix[] = "0506";
$phoneprefix[] = "0601";
$phoneprefix[] = "0602";
$phoneprefix[] = "0603";
$phoneprefix[] = "0604";
$phoneprefix[] = "0605";
$phoneprefix[] = "0606";
$phoneprefix[] = "0607";
$phoneprefix[] = "0608";
$phoneprefix[] = "0609";
$phoneprefix[] = "0691";
$phoneprefix[] = "0692";
$phoneprefix[] = "8";
$phoneprefix[] = "6";
$phoneprefix[] = "5";
$phoneprefix[] = "4";
$phoneprefix[] = "3";

$emaildomains[] = "wp.pl";
$emaildomains[] = "home.net";
$emaildomains[] = "nowhere.net";
$emaildomains[] = "gmail.com";
$emaildomains[] = "yahoo.com";
$emaildomains[] = "comtv.ru";

$producer[] = "3Com";
$producer[] = "Planet";
$producer[] = "Cisco";
$producer[] = "Micronet";
$producer[] = "Surecom";
$producer[] = "D-Link";

function mkpw($nchars)
{
	$allowed='0123456789ABCDEF';
	mt_srand ((double) microtime() * 100000000);
	$return = '';
	while (strlen($return)<$nchars) 
		$return .= $allowed[mt_rand(0,strlen($allowed)-1)];
	return $return;
}
				
function makemac()
{
	for($i = 0; $i < 6; $i ++)
		$mac[] = mkpw(2);
	return join(':',$mac);
}

if(isset($_GET['l']) && sprintf('%d',$_GET['l']) > 0 && sprintf('%d',$_GET['l']) <= 65000)
{
	$layout['nomenu'] = TRUE;
	$SMARTY->display('header.html');
	echo '<BLOCKQUOTE><BR><H1>'.trans('Generating random data').'</H1>';

	echo '<B>'.trans('Clearing database...').'</B><BR>'; flush();
	$DB->Execute('DELETE FROM nodes');
	$DB->Execute('DELETE FROM divisions');
	$DB->Execute('DELETE FROM customers');
	$DB->Execute('DELETE FROM cash');
	$DB->Execute('DELETE FROM assignments');
	$DB->Execute('DELETE FROM networks');
	$DB->Execute('DELETE FROM tariffs');
	$DB->Execute('DELETE FROM payments');	
	$DB->Execute('DELETE FROM netdevices');
	$DB->Execute('DELETE FROM netlinks');
	$DB->Execute('DELETE FROM documents');
	$DB->Execute('DELETE FROM taxes');
	$DB->Execute('DELETE FROM invoicecontents');
	$DB->Execute('DELETE FROM receiptcontents');
	
	if($CONFIG['database']['type']=='postgres')
	{
		$DB->Execute('DROP SEQUENCE "nodes_id_seq"; CREATE SEQUENCE "nodes_id_seq"');
		$DB->Execute('DROP SEQUENCE "divisions_id_seq"; CREATE SEQUENCE "divisions_id_seq"');
		$DB->Execute('DROP SEQUENCE "customers_id_seq"; CREATE SEQUENCE "customers_id_seq"');
		$DB->Execute('DROP SEQUENCE "cash_id_seq";  CREATE SEQUENCE "cash_id_seq"');
		$DB->Execute('DROP SEQUENCE "assignments_id_seq";CREATE SEQUENCE "assignments_id_seq"');
		$DB->Execute('DROP SEQUENCE "networks_id_seq";   CREATE SEQUENCE "networks_id_seq"');
		$DB->Execute('DROP SEQUENCE "tariffs_id_seq";    CREATE SEQUENCE "tariffs_id_seq"');
		$DB->Execute('DROP SEQUENCE "netdevices_id_seq"; CREATE SEQUENCE "netdevices_id_seq"');
		$DB->Execute('DROP SEQUENCE "netlinks_id_seq";   CREATE SEQUENCE "netlinks_id_seq"');
		$DB->Execute('DROP SEQUENCE "documents_id_seq";  CREATE SEQUENCE "documents_id_seq"');
		$DB->Execute('DROP SEQUENCE "taxes_id_seq";  CREATE SEQUENCE "taxes_id_seq"');
	}
	elseif($CONFIG['database']['type'] == 'mysql' || $CONFIG['database']['type'] == 'mysqli')
	{
		$DB->Execute('ALTER TABLE customers auto_increment=0');
		$DB->Execute('ALTER TABLE divisions auto_increment=0');
		$DB->Execute('ALTER TABLE nodes auto_increment=0');
		$DB->Execute('ALTER TABLE netdevices auto_increment=0');
		$DB->Execute('ALTER TABLE tariffs auto_increment=0');
		$DB->Execute('ALTER TABLE taxes auto_increment=0');
	}

	$DB->Execute('INSERT INTO divisions (name, shortname) VALUES(?,?)', array('default', 'default'));

	$DB->Execute('INSERT INTO taxes (label, value, taxed) VALUES(?,?,?)',array('tax-free', 0, 0));
	$DB->Execute('INSERT INTO taxes (label, value, taxed) VALUES(?,?,?)',array('7%', 7, 1));
	$DB->Execute('INSERT INTO taxes (label, value, taxed) VALUES(?,?,?)',array('22%', 22, 1));

	echo '<B>'.trans('Generating subscriptions...').'</B><BR>'; flush();
	$tariffdata = array( 'name' => 'Lite', 'description' => 'Lite Tariff', 
			    'value' => '30', 'taxid' => '1', 'prodid' => '', 
			    'uprate' => '64', 'upceil' => '64', 
			    'downrate' => '128', 'downceil' => '128', 
			    'climit' => '0', 'plimit' => '0', 'dlimit' => 0,
			    'sh_limit' => 0, 'www_limit' => 0, 'mail_limit' => 0, 'sql_limit' => 0, 'ftp_limit' => 0,
			    'quota_sh_limit' => 0, 'quota_www_limit' => 0, 'quota_mail_limit' => 0, 'quota_sql_limit' => 0, 'quota_ftp_limit' => 0,
			    'domain_limit' => 0, 'alias_limit' => 0,
			    'type' => TARIFF_INTERNET);
	$LMS->TariffAdd($tariffdata);
	$tariffdata = array( 'name' => 'Standart', 'description' => 'Standart Tariff', 
			    'value' => '60', 'taxid' => '2', 'prodid' => '', 
			    'uprate' => '128', 'upceil' => '128', 
			    'downrate' => '256', 'downceil' => '256', 
			    'climit' => '0', 'plimit' => '0', 'dlimit' => 0,
			    'sh_limit' => 0, 'www_limit' => 0, 'mail_limit' => 0, 'sql_limit' => 0, 'ftp_limit' => 0,
			    'quota_sh_limit' => 0, 'quota_www_limit' => 0, 'quota_mail_limit' => 0, 'quota_sql_limit' => 0, 'quota_ftp_limit' => 0,
			    'domain_limit' => 0, 'alias_limit' => 0,
			    'type' => TARIFF_INTERNET);
	$LMS->TariffAdd($tariffdata);
	$tariffdata = array( 'name' => 'Gold', 'description' => 'Gold Tariff', 
			    'value' => '120', 'taxid' => '3', 'prodid' => '', 
			    'uprate' => '256', 'upceil' => '256', 
			    'downrate' => '512', 'downceil' => '512', 
			    'climit' => '0', 'plimit' => '0', 'dlimit' => 0,
			    'sh_limit' => 0, 'www_limit' => 0, 'mail_limit' => 0, 'sql_limit' => 0, 'ftp_limit' => 0,
			    'quota_sh_limit' => 0, 'quota_www_limit' => 0, 'quota_mail_limit' => 0, 'quota_sql_limit' => 0, 'quota_ftp_limit' => 0,
			    'domain_limit' => 0, 'alias_limit' => 0,
			    'type' => TARIFF_INTERNET);
	$LMS->TariffAdd($tariffdata);

	echo '<B>'.trans('Generating payments...').'</B><BR>'; flush();
	$paymentdata = array( 'name' => 'DSL-2048', 'description' => 'Internet Link subscription', 'value' => '200', 'creditor' => 'Internet Super Provider Ltd.', 'period' => MONTHLY, 'at' => '10');
	$LMS->PaymentAdd($paymentdata);
	$paymentdata = array( 'name' => 'Server Room', 'description' => 'Rent', 'value' => '300', 'creditor' => 'Residential Cooperative "VIEW"', 'period' => MONTHLY, 'at' => '20');
	$LMS->PaymentAdd($paymentdata);
	$paymentdata = array( 'name' => 'Domain', 'description' => 'Domain "our.net" subscription', 'value' => '150', 'creditor' => 'NASK', 'period' => YEARLY, 'at' => '31');
	$LMS->PaymentAdd($paymentdata);
	
	echo '<B>'.trans('Generating network...').'</B><BR>'; flush();
	$prefix = ($_GET['l']*2>1024) ? 16 : 22;
	$netdata = array( 'name' => 'LAN1', 'address' => '192.168.0.0', 'prefix' => $prefix, 'gateway' => '192.168.0.1', 'dns' => '192.168.0.1', 'dns2' => '192.168.3.254', 'domain' => 'ultralan.net', 'wins' => '192.168.0.2', 'dhcpstart' => '192.168.3.230', 'dhcpend' => '192.168.3.253', 'interface' => 'eth0');
	$LMS->NetworkAdd($netdata);

	echo '<B>'.trans('Generating customers...').'</B><BR>';	flush();
	$startip = ip_long('192.168.0.0')+1;
	$cnt = 0;
	$lnsize = sizeof($lastnames);
	$nsize = sizeof($names);
	$nodsize = sizeof($nodenames);
	$ppsize = sizeof($phoneprefix);
	$ssize = sizeof($streets);
	$esize = sizeof($emaildomains);
	for($i = 0; $i < sprintf('%d',$_GET['l']); $i++)
	{
		$customeradd['lastname'] = $lastnames[mt_rand(0,$lnsize-1)];
		$customeradd['name'] = $names[mt_rand(0,$nsize-1)];
		$customeradd['phone'] = $phoneprefix[mt_rand(0,$ppsize-1)];
		for($j = 0; $j < 6; $j++)
			$customeradd['phone'] .= mt_rand(0,9);
		$street = mt_rand(0,$ssize-1);
		$customeradd['address'] = $streets[$street].' '.mt_rand(1,50).'/'.mt_rand(1,300);
		$customeradd['zip'] = '03-7'.sprintf('%02d',$street);
		$customeradd['city'] = 'Mahagonny';
		$customeradd['email'] = strtolower($customeradd['name']).'.'.strtolower($customeradd['lastname']).'@'.$emaildomains[mt_rand(0,$esize-1)];
		$customeradd['status'] = 3;
		$customeradd['tariff'] = mt_rand(1,3);
		$customeradd['payday'] = mt_rand(1,28);
		$customeradd['im'] = 0;
		$customeradd['ten'] = '';
		$customeradd['ssn'] = '';
		$customeradd['regon'] = '';
		$customeradd['rbe'] = '';
		$customeradd['icn'] = '';
		$customeradd['notes'] = '';
		$customeradd['serviceaddr'] = '';
		$customeradd['info'] = '';
		$customeradd['message'] = '';
		$customeradd['pin'] = mt_rand(10000,99999);
		$customeradd['cutoffstop'] = 0;
		$customeradd['divisionid'] = 1;
		$customeradd['consentdate'] = 0;
		$customeradd['paytime'] = -1;

		$id = $LMS->CustomerAdd($customeradd);
		$LMS->AddAssignment(array(
			'tariffid' => $customeradd['tariff'],
			'customerid' => $id,
			'period' => MONTHLY,
			'at' => $customeradd['payday'], 
			'invoice' => 0, 
			'datefrom' => 0, 
			'dateto' => 0, 
			'discount' => 0, 
			'settlement' => 0, 
			'nodes' => NULL
		));
		$DB->Execute('INSERT INTO customercontacts (customerid, phone) VALUES (?, ?)', array($id, $customeradd['phone']));

		$nodes = mt_rand(1,2);
		for($j = 0; $j < $nodes; $j++)
		{
			$nodedata['name'] = $nodenames[mt_rand(0,$nodsize-1)].$i;
			$cnt++;
			$startip++;
			$nodedata['ipaddr'] = long2ip($startip);
			$nodedata['ipaddr_pub'] = '0.0.0.0';
			$nodedata['mac'] = makemac();
			$nodedata['ownerid'] = $id;
			$nodedata['access'] = 1;
			$nodedata['warning'] = 0;
			$nodedata['info'] = '';
			$nodedata['passwd'] = '';
			$nodedata['netdev'] = 0;
			$nodedata['location'] = '';
			$nodedata['chkmac'] = 1;
			$nodedata['halfduplex'] = 0;
			if($nodeid = $LMS->NodeAdd($nodedata))
				$DB->Execute('UPDATE nodes SET lastonline=? WHERE id=? ', array(mt_rand(time()-2592000,time()+2592000),$nodeid));
		}
		$startip ++;
	}
	
	echo '<B>'.trans('Generating network hardware and connections...').'</B><BR>'; flush();
	$nodes = $DB->GetOne('SELECT count(id) FROM nodes');
	$sprod = sizeof($producer);
	$i = 0;
	while($nodes)
	{
		$i++;
		$prod = mt_rand(0,$sprod-1);
		$LMS->NetDevAdd(array(
			'name' => 'SWITCH_'.$i,
			'location' => $streets[mt_rand(0,$ssize-1)].' '.mt_rand(1,50),
			'description' => '',
			'producer' => $producer[$prod],
			'model' => '10/100 Mbps Switch',
			'serialnumber' => ($i*1000000+$i*200000).'-'.($i*11111).'-'.($i*33),
			'ports' => '16',
			'purchasetime' => 0,
			'guaranteeperiod' => NULL,
			'info' => ''));
		$ports = mt_rand(4,14);
		for($j = 0; $j < $ports; $j++)
		{
			if(!$nodes) break;
			$LMS->NetDevLinkNode($nodes,$i);
			$nodes--;
		}
		$ip['ownerid'] = 0;
		$ip['ipaddr'] = long2ip($startip);
		$ip['ipaddr_pub'] = '0.0.0.0';
		$ip['mac'] = makemac();
		$ip['name'] = 'SWITCH_'.$i;
		$ip['access'] = 1;
		$ip['warning'] = 0;
		$ip['info'] = '';
		$ip['passwd'] = '';
		$ip['netdev'] = $i;
		$startip++;
		if($i>1)
			$LMS->NetDevLink($i,$i-1);
	}
	
	if($_GET['i'])
	{
		echo '<B>'.trans('Generating invoices...').'</B><BR>'; flush();
		
		if($_GET['i'] > 100) $_GET['i'] = 100;
		
		$inv['number'] = 0;
		$inv['paytime'] = 14;
		$inv['paytype'] = trans('CASH');
		$inv['numberplanid'] = 0;
		$inv['type'] = DOC_INVOICE;
		$inv['cdate'] = time() - ($_GET['i']+1) * 86400;
		$contents['prodid'] = '';
		$contents['tariffid'] = 0;
		$contents['jm'] = trans('pcs.');
		$contents['name'] = trans('Subscription');
		
		$customers = $DB->GetAll('SELECT '.$DB->Concat('UPPER(lastname)',"' '",'customers.name').' AS customername,
				id, ssn, address, zip, city, ten, divisionid FROM customers');
					    
		if($customers)
			for($n=0; $n<$_GET['i']; $n++)
			{
				$contents['taxid'] = mt_rand(1,3);
				$contents['count'] = mt_rand(1,3);
				$contents['valuebrutto'] = 100+$n*10+$n*0.1;
				$contents['discount'] = 0;
				$inv['cdate'] += 86400;
				
				foreach($customers as $c)
				{
					$inv['number']++;
					$cont[0] = $contents;
					$LMS->AddInvoice(array('customer' => $c, 'contents' => $cont, 'invoice' => $inv));
				}
			}
	}			

	echo '<P><B><A HREF="javascript:window.close();">'.trans('You can close this window now.').'</A></B></BLOCKQUOTE>';
	$SMARTY->display('footer.html');
}
else
{
	$SMARTY->display('header.html');
	echo '<H1>'.trans('Generating random data').'</H1>';
	echo '<form method="get" action="?" target="_blank">';
	echo '<input type="hidden" name="m" value="genfake">';
	echo '<input type="submit" class="hiddenbtn">';
	echo '<font class="alert bold">'.trans('WARNING! THIS WILL DELETE ALL DATA FROM DATABASE!!!').'</font><p>';
	echo trans('How many customers? (max.65000):').' <input type="text" name="l" size="5"><br>';
	echo trans('How many invoices for each customer? (max.100):').' <input type="text" name="i" size="5">';
	echo '<br><input type="submit" value="'.trans('Generate').'"></form>';
	$SMARTY->display('footer.html');
}

?>

